import json  # Import the json module

from qwen_agent.agents import Assistant

# Define LLM
llm_cfg = {
    'model': 'qwen3:0.6B',

    # Use the endpoint provided by Alibaba Model Studio:
    # 'model_type': 'qwen_dashscope',
    # 'api_key': os.getenv('DASHSCOPE_API_KEY'),

    # Use a custom endpoint compatible with OpenAI API:
    'model_server': 'http://localhost:11434/v1',  # api_base
    'api_key': 'EMPTY',

    # Other parameters:
    # 'generate_cfg': {
    #         # Add: When the response content is `<think>this is the thought</think>this is the answer;
    #         # Do not add: When the response has been separated by reasoning_content and content.
    #         'thought_in_content': True,
    #     },
}

# Define Tools
tools = [
    {'mcpServers': {  # You can specify the MCP configuration file
        'time': {
            'command': 'uvx',
            'args': ['mcp-server-time', '--local-timezone=Asia/Shanghai']
        },
        "fetch": {
            "command": "uvx",
            "args": ["mcp-server-fetch"]
        },
        "ddg-search": {
            "command": "uvx",
            "args": ["duckduckgo-mcp-server"]
        }
    }
    },
    'code_interpreter',  # Built-in tools
]

# Define Agent
bot = Assistant(llm=llm_cfg, function_list=tools)

# Streaming generation
messages = [{'role': 'user',
             'content': 'Write a 500 word blog post about the latest qwen 3 model. Use the search tool, and fetch the top 3 articles before you write the post. Write in a casual, but factual style - no hyperbole. Provide references to the webpages in the output.'}]

final_responses = None
# Consider adding error handling around bot.run
try:
    for responses in bot.run(messages=messages, enable_thinking=True, max_tokens=30000):
        print(".", end="", flush=True)
        final_responses = responses.pop()
except Exception as e:
    print(f"An error occurred during agent execution: {e}")

# Pretty-print the final response object
if final_responses:
    print("--- Full Response Object ---")
    print(json.dumps(final_responses, indent=2))  # Use indent=2 (or 4) for pretty printing
    print("\n--- Extracted Content ---")
    print(final_responses.get('content', 'No content found in response.'))  # Use .get for safer access
else:
    print("No final response received from the agent.")
